@@ -1,15 +1,17 @@
 from ..variables import EdgeSelected
 from .constraint import Constraint
-import pylp
+import ilpy
 
 
 class MaxChildren(Constraint):
-    """Ensures that every selected node has no more than ``max_children``
+    r"""Ensures that every selected node has no more than ``max_children``
     selected edges to the next frame.
 
-    Adds the following linear constraint for each node::
+    Adds the following linear constraint for each node :math:`v`:
 
-      sum(next) <= max_children
+    .. math::
+
+      \sum_{e \in \\text{out_edges}(v)} x_e \leq \\text{max_children}
 
     Args:
 
@@ -28,14 +30,14 @@ class MaxChildren(Constraint):
         constraints = []
         for node in solver.graph.nodes:
 
-            constraint = pylp.LinearConstraint()
+            constraint = ilpy.LinearConstraint()
 
-            # all incoming edges
+            # all outgoing edges
             for edge in solver.graph.next_edges(node):
                 constraint.set_coefficient(edge_indicators[edge], 1)
 
             # relation, value
-            constraint.set_relation(pylp.Relation.LessEqual)
+            constraint.set_relation(ilpy.Relation.LessEqual)
 
             constraint.set_value(self.max_children)
             constraints.append(constraint)
