@@ -1,15 +1,17 @@
 from ..variables import EdgeSelected
 from .constraint import Constraint
-import pylp
+import ilpy
 
 
 class MaxParents(Constraint):
-    """Ensures that every selected node has no more than ``max_parents``
+    r"""Ensures that every selected node has no more than ``max_parents``
     selected edges to the previous frame.
 
-    Adds the following linear constraint for each node::
+    Adds the following linear constraint for each node :math:`v`:
 
-      sum(prev) <= max_parents
+    .. math::
+
+      \sum_{e \in \\text{in_edges}(v)} x_e \leq \\text{max_parents}
 
     Args:
 
@@ -28,14 +30,14 @@ class MaxParents(Constraint):
         constraints = []
         for node in solver.graph.nodes:
 
-            constraint = pylp.LinearConstraint()
+            constraint = ilpy.LinearConstraint()
 
             # all incoming edges
             for edge in solver.graph.prev_edges(node):
                 constraint.set_coefficient(edge_indicators[edge], 1)
 
             # relation, value
-            constraint.set_relation(pylp.Relation.LessEqual)
+            constraint.set_relation(ilpy.Relation.LessEqual)
 
             constraint.set_value(self.max_parents)
             constraints.append(constraint)
