@@ -1,15 +1,17 @@
 from ..variables import NodeSelected, EdgeSelected
 from .constraint import Constraint
-import pylp
+import ilpy
 
 
 class SelectEdgeNodes(Constraint):
-    """Ensures that if an edge (u, v) is selected, u and v have to be selected
-    as well.
+    r"""Ensures that if an edge :math:`(u, v)` is selected, :math:`u` and
+    :math:`v` have to be selected as well.
 
-    Adds the following linear constraint for each edge::
+    Adds the following linear constraint for each edge :math:`e = (u,v)`:
 
-      2 * edge(u, v) - u - v <= 0
+    .. math::
+
+      2 x_e - x_u - x_v \leq 0
 
     This constraint will be added by default to any :class:`Solver` instance.
     """
@@ -28,11 +30,11 @@ class SelectEdgeNodes(Constraint):
             ind_u = node_indicators[u]
             ind_v = node_indicators[v]
 
-            constraint = pylp.LinearConstraint()
+            constraint = ilpy.LinearConstraint()
             constraint.set_coefficient(ind_e, 2)
             constraint.set_coefficient(ind_u, -1)
             constraint.set_coefficient(ind_v, -1)
-            constraint.set_relation(pylp.Relation.LessEqual)
+            constraint.set_relation(ilpy.Relation.LessEqual)
             constraint.set_value(0)
             constraints.append(constraint)
 
