@@ -3,6 +3,14 @@ from .costs import Costs
 
 
 class Split(Costs):
+    """Costs for :class:`motile.variables.NodeSplit` variables.
+
+    Args:
+
+        constant (float):
+            A constant cost for each node that has more than one selected
+            child.
+    """
 
     def __init__(self, constant):
 
